Hint: Use C-x t to copy tagged file names to the command line.

Συμβουλή: Πατώντας C-x p μπορείτε να αντιγράψετε την τρέχουσα τοποθεσία στη γραμμή εντολών.

Συμβουλή: Πατήστε M-Tab (ή Esc+Tab) για συμπλήρωση. Πατήστε το δύο φορές για να δείτε μια λίστα.

Συμβουλή: Πατήστε M-p και M-n για να δείτε το ιστορικό εντολών.

Hint: Need to quote a character? Use Control-q and the character.

Hint: Tired of these messages? Turn them off from the Options/Layout menu.

Hint: Selecting directories: add a slash to the end of the matching pattern.

Hint: If your terminal lacks functions keys, use the ESC+number sequence.

Συμβουλή: Η ιστοσελίδα του GNU Midnight Commander: http://www.midnight-commander.org/

Συμβουλή: Παρακαλούμε στείλτε μας αναφορές σφαλμάτων στο mc-devel@gnome.org

Hint: Tab changes your current panel.

Hint: VFS coolness: tap enter on a tar file to examine its contents.

Hint: We also have a nice manual page.

Hint: Do you want Lynx-style navigation? Set it in the Configuration dialog.

Hint: % macros work even on the command line.

Συμβουλή: Το M-! θα σας επιτρέψει να εκτελέσετε προγράμματα και να δείτε την έξοδο στον προβολέα.

Συμβουλή: Η μορφή της λίστας αρχείων μπορεί να προσαρμοστεί. Πατήστε "man mc" για λεπτομέρειες.

Hint: %D/%T expands to the tagged files in the opposite directory.

Συμβουλή: Θέλετε ένα σκέτο κέλυφος; Πατήστε C-o, και ελάτε πίσω στο MC με C-o ξανά.

Hint: Setting the CDPATH variable can save you keystrokes in cd commands.

Συμβουλή: Αν θέλετε να βλέπετε τα αρχεία .* , πείτε το στο διάλογο ρυθμίσεων.

Συμβουλή: Θέλετε να βλέπετε τα αρχεία *~; Ρυθμίστε το στο διάλογο ρυθμίσεων

Hint: Completion works on all input lines in all dialogs. Just press M-Tab.

Συμβουλή: Για αργά τερματικά ίσως μπορεί να βοηθήσει η σημαία -s.

Hint: Find File: you can work on the files found using the Panelize button.

Hint: Want to do complex searches? Use the External Panelize command.

Συμβουλή: Για να αλλάξετε κατάλογο ενώ έχετε ήδη ξεκινήσει να πληκτρολογείτε μία εντολή, χρησιμοποιήστε το M-c (γρήγορο cd).

Σημείωση: Οι εντολές κελύφους δε θα λειτουργήσουν όταν βρίσκεστε σε ένα μη τοπικό σύστημα αρχείων.

Hint: Bring text back from the dead with C-y.

Συμβουλή: Μήπως κάποια από τα πλήκτρα σας δε λειτουργούν; Δείτε το Επιλογές/Εκμάθηση πλήκτρων.

Συμβουλή: Για να δείτε την έξοδο μιας εντολής στον προβολέα, χρησιμοποιήστε το M-!

Hint: F13 (or Shift-F3) invokes the viewer in raw mode.

Hint: You may specify the editor for F4 with the shell variable EDITOR.

Συμβουλή: Μπορείτε να ρυθμίσετε τον εξωτερικό προβολέα με τις μεταβλητές κελύφους VIEWER ή PAGER.

Συμβουλή: Μπορείτε να απενεργοποιήσετε όλα τα ερωτήματα επιβεβαίωσης στο Επιλογές/Επιβεβαίωση

Hint: Leap to frequently used directories in a single bound with C-\.

Συμβουλή: Μπορείτε να κάνετε ανώνυμο FTP με το mc πληκτρολογώντας 'cd ftp://machine.edu'

Συμβουλή: Το Midnight Commander έχει ενσωματωμένο FTP, δείτε το μενού Αρχείο/FTP.

Συμβουλή: Το M-t αλλάζει γρήγορα τη λειτουργία λίστας.

Συμβουλή: Μπορείτε να ρυθμίσετε το όνομα χρήστη όταν κάνετε ftps: 'cd ftp://user@machine.edu'

Συμβουλή: Μπορείτε να περιηγηθείτε σε αρχεία RPM πατώντας enter πάνω σε ένα αρχείο rpm.

Hint: To mark directories on the select dialog box, append a slash.

Συμβουλή: Η χρήση αντιγραφής και επικόλλησης με το ποντίκι μπορεί να απαιτεί να πατάτε το πλήκτρο shift

Hint: Key frequently visited ftp sites in the hotlist: type C-\.
